@@ -233,7 +233,7 @@ class DrivenControl:
         """
 
         amplitudes = np.sqrt(
-            self.amplitude_x ** 2 + self.amplitude_y ** 2 + self.detunings ** 2
+            self.amplitude_x**2 + self.amplitude_y**2 + self.detunings**2
         )
         angles = amplitudes * self.durations
 
@@ -252,7 +252,7 @@ class DrivenControl:
             :math:`\mathbf v_n=(\Omega_n\cos\phi_n, \Omega_n\sin\phi_n, \Delta_n)`.
         """
         amplitudes = np.sqrt(
-            self.amplitude_x ** 2 + self.amplitude_y ** 2 + self.detunings ** 2
+            self.amplitude_x**2 + self.amplitude_y**2 + self.detunings**2
         )
 
         # Reduces tolerance of the comparison to zero in case the units chosen
@@ -442,7 +442,7 @@ class DrivenControl:
 
             # note that the newline parameter here is necessary
             # see details at https://docs.python.org/3/library/csv.html#id3
-            with open(filename, "w", newline="") as file:
+            with open(filename, "w", encoding="utf-8", newline="") as file:
                 writer = csv.DictWriter(file, fieldnames=field_names)
                 writer.writeheader()
                 for index in range(self.number_of_segments):
@@ -450,7 +450,7 @@ class DrivenControl:
                         {name: control_info[name][index] for name in field_names}
                     )
         else:
-            with open(filename, "wt") as handle:
+            with open(filename, "wt", encoding="utf-8") as handle:
                 json.dump(control_info, handle, sort_keys=True, indent=4)
 
     def export_to_file(
@@ -527,21 +527,20 @@ class DrivenControl:
         check_arguments(
             file_format in _file_formats,
             "Requested file format is not supported. Please use "
-            "one of {}".format(_file_formats),
+            f"one of {_file_formats}",
             {"file_format": file_format},
         )
 
         check_arguments(
             file_type in _file_types,
-            "Requested file type is not supported. Please use "
-            "one of {}".format(_file_types),
+            "Requested file type is not supported. Please use " f"one of {_file_types}",
             {"file_type": file_type},
         )
 
         check_arguments(
             coordinates in _coordinate_systems,
             "Requested coordinate type is not supported. Please use "
-            "one of {}".format(_coordinate_systems),
+            f"one of {_coordinate_systems}",
             {"coordinates": coordinates},
         )
 
@@ -619,10 +618,10 @@ class DrivenControl:
         """
         Prepares a friendly string format for a Driven Control.
         """
-        driven_control = list()
+        driven_control = []
 
         if self.name is not None:
-            driven_control.append("{}:".format(self.name))
+            driven_control.append(f"{self.name}:")
 
         pretty_rabi_rates = ",".join(
             [
@@ -651,17 +650,13 @@ class DrivenControl:
         )
 
         driven_control.append(
-            "Rabi Rates = [{}] x {}".format(pretty_rabi_rates, self.maximum_rabi_rate)
+            f"Rabi Rates = [{pretty_rabi_rates}] x {self.maximum_rabi_rate}"
         )
+        driven_control.append(f"Azimuthal Angles = [{pretty_azimuthal_angles}] x pi")
         driven_control.append(
-            "Azimuthal Angles = [{}] x pi".format(pretty_azimuthal_angles)
-        )
-        driven_control.append(
-            "Detunings = [{}] x {}".format(pretty_detuning, self.maximum_detuning)
-        )
-        driven_control.append(
-            "Durations = [{}] x {}".format(pretty_durations, self.duration)
+            f"Detunings = [{pretty_detuning}] x {self.maximum_detuning}"
         )
+        driven_control.append(f"Durations = [{pretty_durations}] x {self.duration}")
         driven_control_string = "\n".join(driven_control)
 
         return driven_control_string
